==> hibiscus.js-1.2.1.tgz: package/popconfirm/popconfirm.directive.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { ComponentFactoryResolver, Directive, ElementRef, Renderer2, ViewContainerRef } from '@angular/core';
import { TooltipDirective } from '../tooltip/tooltip.directive';
import { PopconfirmComponent } from './popconfirm.component';
var PopconfirmDirective = /** @class */ (function (_super) {
    __extends(PopconfirmDirective, _super);
    function PopconfirmDirective(elementRef, hostView, resolver, renderer, tooltip) {
        return _super.call(this, elementRef, hostView, resolver, renderer, tooltip) || this;
    }
    PopconfirmDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hi-popconfirm]'
                },] },
    ];
    /** @nocollapse */
    PopconfirmDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: ViewContainerRef, },
        { type: ComponentFactoryResolver, },
        { type: Renderer2, },
        { type: PopconfirmComponent, },
    ]; };
    return PopconfirmDirective;
}(TooltipDirective));
export { PopconfirmDirective };

==> hibiscus.js-1.2.3.tgz: package/popconfirm/popconfirm.directive.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { ComponentFactoryResolver, Directive, ElementRef, Renderer2, ViewContainerRef } from '@angular/core';
import { TooltipDirective } from '../tooltip/tooltip.directive';
import { PopconfirmComponent } from './popconfirm.component';
var PopconfirmDirective = (function (_super) {
    __extends(PopconfirmDirective, _super);
    function PopconfirmDirective(elementRef, hostView, resolver, renderer, tooltip) {
        return _super.call(this, elementRef, hostView, resolver, renderer, tooltip) || this;
    }
    PopconfirmDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hi-popconfirm]'
                },] },
    ];
    PopconfirmDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: ViewContainerRef, },
        { type: ComponentFactoryResolver, },
        { type: Renderer2, },
        { type: PopconfirmComponent, },
    ]; };
    return PopconfirmDirective;
}(TooltipDirective));
export { PopconfirmDirective };
